@@ -124,9 +124,7 @@ class ColorfulMeta(type):
     out = _ColorfulOut("out", (object,), {})
 
     def __getattr__(cls, attr):
-        def _decoratedText(text):
-            return ColorfulParser.parse_attr(attr) % text
-        return _decoratedText
+        return cls.get(attr)
 
     def has_forecolor(self, color):
         return ColorfulParser.foreground_color_exists(color)
@@ -134,4 +132,16 @@ class ColorfulMeta(type):
     def has_backcolor(self, color):
         return ColorfulParser.background_color_exists(color)
 
+    def exists(self, attr):
+        try:
+            ColorfulParser.parse_attr(attr)
+            return True
+        except ANSISequenceNotFoundError:
+            return False
+
+    def get(self, attr):
+        def _decoratedText(text):
+            return ColorfulParser.parse_attr(attr) % text
+        return _decoratedText
+
 colorful = ColorfulMeta("colorful", (object, ), {})  # use metaclass ColorfulMeta for Colorful class
